import {useCallback, useState} from 'react';
import {addEdge, applyEdgeChanges, applyNodeChanges, Background, Controls, ReactFlow} from "@xyflow/react";
import '@xyflow/react/dist/style.css';
import {SidebarInset, SidebarProvider, SidebarTrigger} from "@/components/ui/sidebar.tsx";
import { AppSidebar } from './components/app-sidebar';
import {Separator } from './components/ui/separator';
import {Breadcrumb, BreadcrumbItem, BreadcrumbLink, BreadcrumbList, BreadcrumbPage, BreadcrumbSeparator } from './components/ui/breadcrumb';

const initialNodes = [
  {
    id: '1',
    data: {label: 'Hello'},
    position: {x: 0, y: 0},
    type: 'input',
  },
  {
    id: '2',
    data: {label: 'World'},
    position: {x: 100, y: 100},
  },
];
// const initialEdges = [
//   { id: '1-2', source: '1', target: '2', label: 'to the', type: 'step' },
// ];

function App() {
  const [nodes, setNodes] = useState(initialNodes);
  const [edges, setEdges] = useState([]);

  const onNodesChange = useCallback(
    (changes: any) => setNodes((nds) => applyNodeChanges(changes, nds)),
    [],
  );
  const onEdgesChange = useCallback(
    (changes: any) => setEdges((eds) => applyEdgeChanges(changes, eds)),
    [],
  );
  const onConnect = useCallback(
    // @ts-ignore
    (params: any) => setEdges((eds) => addEdge(params, eds)),
    [],
  );

  return (
    <>
      <SidebarProvider>
        <AppSidebar />
        <SidebarInset>
          <header className="rf:flex rf:sticky rf:top-0 rf:bg-background rf:h-16 rf:shrink-0 rf:items-center rf:gap-2 rf:border-b rf:px-4">
            <SidebarTrigger className="rf:-ml-1" />
            <Separator orientation="vertical" className="rf:mr-2 rf:h-4" />
            <Breadcrumb>
              <BreadcrumbList>
                <BreadcrumbItem className="rf:hidden rf:md:block">
                  <BreadcrumbLink href="#">
                    Building Your Application
                  </BreadcrumbLink>
                </BreadcrumbItem>
                <BreadcrumbSeparator className="rf:hidden rf:md:block" />
                <BreadcrumbItem>
                  <BreadcrumbPage>Data Fetching</BreadcrumbPage>
                </BreadcrumbItem>
              </BreadcrumbList>
            </Breadcrumb>
          </header>
          <div className="rf:flex rf:flex-1 rf:flex-col">
            <ReactFlow
              nodes={nodes}
              onNodesChange={onNodesChange}
              edges={edges}
              onEdgesChange={onEdgesChange}
              onConnect={onConnect}
            >
              <Background bgColor="#fff"/>
              <Controls/>
            </ReactFlow>
          </div>
        </SidebarInset>
      </SidebarProvider>
    </>
  );
}

export default App;
