import * as React from "react"
import { Slot } from "@radix-ui/react-slot"
import { cva, type VariantProps } from "class-variance-authority"

import { cn } from "@/lib/utils"

const buttonVariants = cva(
  "rf:inline-flex rf:items-center rf:justify-center rf:gap-2 rf:whitespace-nowrap rf:rounded-md rf:text-sm rf:font-medium rf:transition-all rf:disabled:pointer-events-none rf:disabled:opacity-50 rf:[&_svg]:pointer-events-none rf:[&_svg:not([class*=size-])]:size-4 rf:shrink-0 rf:[&_svg]:shrink-0 rf:outline-none rf:focus-visible:border-ring rf:focus-visible:ring-ring/50 rf:focus-visible:ring-[3px] rf:aria-invalid:ring-destructive/20 rf:dark:aria-invalid:ring-destructive/40 rf:aria-invalid:border-destructive",
  {
    variants: {
      variant: {
        default:
          "rf:bg-primary rf:text-primary-foreground rf:shadow-xs rf:hover:bg-primary/90",
        destructive:
          "rf:bg-destructive rf:text-white rf:shadow-xs rf:hover:bg-destructive/90 rf:focus-visible:ring-destructive/20 rf:dark:focus-visible:ring-destructive/40 rf:dark:bg-destructive/60",
        outline:
          "rf:border rf:bg-background rf:shadow-xs rf:hover:bg-accent rf:hover:text-accent-foreground rf:dark:bg-input/30 rf:dark:border-input rf:dark:hover:bg-input/50",
        secondary:
          "rf:bg-secondary rf:text-secondary-foreground rf:shadow-xs rf:hover:bg-secondary/80",
        ghost:
          "rf:hover:bg-accent rf:hover:text-accent-foreground rf:dark:hover:bg-accent/50",
        link: "rf:text-primary rf:underline-offset-4 rf:hover:underline",
      },
      size: {
        default: "rf:h-9 rf:px-4 rf:py-2 rf:has-[>svg]:px-3",
        sm: "rf:h-8 rf:rounded-md rf:gap-1.5 rf:px-3 rf:has-[>svg]:px-2.5",
        lg: "rf:h-10 rf:rounded-md rf:px-6 rf:has-[>svg]:px-4",
        icon: "rf:size-9",
      },
    },
    defaultVariants: {
      variant: "default",
      size: "default",
    },
  }
)

function Button({
  className,
  variant,
  size,
  asChild = false,
  ...props
}: React.ComponentProps<"button"> &
  VariantProps<typeof buttonVariants> & {
    asChild?: boolean
  }) {
  const Comp = asChild ? Slot : "button"

  return (
    <Comp
      data-slot="button"
      className={cn(buttonVariants({ variant, size, className }))}
      {...props}
    />
  )
}

export { Button, buttonVariants }
