"use client"

import * as React from "react"
import * as SheetPrimitive from "@radix-ui/react-dialog"
import { XIcon } from "lucide-react"

import { cn } from "@/lib/utils"

function Sheet({ ...props }: React.ComponentProps<typeof SheetPrimitive.Root>) {
  return <SheetPrimitive.Root data-slot="sheet" {...props} />
}

function SheetTrigger({
  ...props
}: React.ComponentProps<typeof SheetPrimitive.Trigger>) {
  return <SheetPrimitive.Trigger data-slot="sheet-trigger" {...props} />
}

function SheetClose({
  ...props
}: React.ComponentProps<typeof SheetPrimitive.Close>) {
  return <SheetPrimitive.Close data-slot="sheet-close" {...props} />
}

function SheetPortal({
  ...props
}: React.ComponentProps<typeof SheetPrimitive.Portal>) {
  return <SheetPrimitive.Portal data-slot="sheet-portal" {...props} />
}

function SheetOverlay({
  className,
  ...props
}: React.ComponentProps<typeof SheetPrimitive.Overlay>) {
  return (
    <SheetPrimitive.Overlay
      data-slot="sheet-overlay"
      className={cn(
        "rf:data-[state=open]:animate-in rf:data-[state=closed]:animate-out rf:data-[state=closed]:fade-out-0 rf:data-[state=open]:fade-in-0 rf:fixed rf:inset-0 rf:z-50 rf:bg-black/50",
        className
      )}
      {...props}
    />
  )
}

function SheetContent({
  className,
  children,
  side = "right",
  ...props
}: React.ComponentProps<typeof SheetPrimitive.Content> & {
  side?: "top" | "right" | "bottom" | "left"
}) {
  return (
    <SheetPortal>
      <SheetOverlay />
      <SheetPrimitive.Content
        data-slot="sheet-content"
        className={cn(
          "rf:bg-background rf:data-[state=open]:animate-in rf:data-[state=closed]:animate-out rf:fixed rf:z-50 rf:flex rf:flex-col rf:gap-4 rf:shadow-lg rf:transition rf:ease-in-out rf:data-[state=closed]:duration-300 rf:data-[state=open]:duration-500",
          side === "right" &&
            "rf:data-[state=closed]:slide-out-to-right rf:data-[state=open]:slide-in-from-right rf:inset-y-0 rf:right-0 rf:h-full rf:w-3/4 rf:border-l rf:sm:max-w-sm",
          side === "left" &&
            "rf:data-[state=closed]:slide-out-to-left rf:data-[state=open]:slide-in-from-left rf:inset-y-0 rf:left-0 rf:h-full rf:w-3/4 rf:border-r rf:sm:max-w-sm",
          side === "top" &&
            "rf:data-[state=closed]:slide-out-to-top rf:data-[state=open]:slide-in-from-top rf:inset-x-0 rf:top-0 rf:h-auto rf:border-b",
          side === "bottom" &&
            "rf:data-[state=closed]:slide-out-to-bottom rf:data-[state=open]:slide-in-from-bottom rf:inset-x-0 rf:bottom-0 rf:h-auto rf:border-t",
          className
        )}
        {...props}
      >
        {children}
        <SheetPrimitive.Close className="rf:ring-offset-background rf:focus:ring-ring rf:data-[state=open]:bg-secondary rf:absolute rf:top-4 rf:right-4 rf:rounded-xs rf:opacity-70 rf:transition-opacity rf:hover:opacity-100 rf:focus:ring-2 rf:focus:ring-offset-2 rf:focus:outline-hidden rf:disabled:pointer-events-none">
          <XIcon className="rf:size-4" />
          <span className="rf:sr-only">Close</span>
        </SheetPrimitive.Close>
      </SheetPrimitive.Content>
    </SheetPortal>
  )
}

function SheetHeader({ className, ...props }: React.ComponentProps<"div">) {
  return (
    <div
      data-slot="sheet-header"
      className={cn("rf:flex rf:flex-col rf:gap-1.5 rf:p-4", className)}
      {...props}
    />
  )
}

function SheetFooter({ className, ...props }: React.ComponentProps<"div">) {
  return (
    <div
      data-slot="sheet-footer"
      className={cn("rf:mt-auto rf:flex rf:flex-col rf:gap-2 rf:p-4", className)}
      {...props}
    />
  )
}

function SheetTitle({
  className,
  ...props
}: React.ComponentProps<typeof SheetPrimitive.Title>) {
  return (
    <SheetPrimitive.Title
      data-slot="sheet-title"
      className={cn("rf:text-foreground rf:font-semibold", className)}
      {...props}
    />
  )
}

function SheetDescription({
  className,
  ...props
}: React.ComponentProps<typeof SheetPrimitive.Description>) {
  return (
    <SheetPrimitive.Description
      data-slot="sheet-description"
      className={cn("rf:text-muted-foreground rf:text-sm", className)}
      {...props}
    />
  )
}

export {
  Sheet,
  SheetTrigger,
  SheetClose,
  SheetContent,
  SheetHeader,
  SheetFooter,
  SheetTitle,
  SheetDescription,
}
