import * as React from "react"
import * as TooltipPrimitive from "@radix-ui/react-tooltip"

import { cn } from "@/lib/utils"

function TooltipProvider({
  delayDuration = 0,
  ...props
}: React.ComponentProps<typeof TooltipPrimitive.Provider>) {
  return (
    <TooltipPrimitive.Provider
      data-slot="tooltip-provider"
      delayDuration={delayDuration}
      {...props}
    />
  )
}

function Tooltip({
  ...props
}: React.ComponentProps<typeof TooltipPrimitive.Root>) {
  return (
    <TooltipProvider>
      <TooltipPrimitive.Root data-slot="tooltip" {...props} />
    </TooltipProvider>
  )
}

function TooltipTrigger({
  ...props
}: React.ComponentProps<typeof TooltipPrimitive.Trigger>) {
  return <TooltipPrimitive.Trigger data-slot="tooltip-trigger" {...props} />
}

function TooltipContent({
  className,
  sideOffset = 0,
  children,
  ...props
}: React.ComponentProps<typeof TooltipPrimitive.Content>) {
  return (
    <TooltipPrimitive.Portal>
      <TooltipPrimitive.Content
        data-slot="tooltip-content"
        sideOffset={sideOffset}
        className={cn(
          "rf:bg-primary rf:text-primary-foreground rf:animate-in rf:fade-in-0 rf:zoom-in-95 rf:data-[state=closed]:animate-out rf:data-[state=closed]:fade-out-0 rf:data-[state=closed]:zoom-out-95 rf:data-[side=bottom]:slide-in-from-top-2 rf:data-[side=left]:slide-in-from-right-2 rf:data-[side=right]:slide-in-from-left-2 rf:data-[side=top]:slide-in-from-bottom-2 rf:z-50 rf:w-fit rf:origin-(--radix-tooltip-content-transform-origin) rf:rounded-md rf:px-3 rf:py-1.5 rf:text-xs rf:text-balance",
          className
        )}
        {...props}
      >
        {children}
        <TooltipPrimitive.Arrow className="rf:bg-primary rf:fill-primary rf:z-50 rf:size-2.5 rf:translate-y-[calc(-50%_-_2px)] rf:rotate-45 rf:rounded-[2px]" />
      </TooltipPrimitive.Content>
    </TooltipPrimitive.Portal>
  )
}

export { Tooltip, TooltipTrigger, TooltipContent, TooltipProvider }
