import * as React from "react"
import { Check, ChevronsUpDown, GalleryVerticalEnd } from "lucide-react"

import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu"
import {
  SidebarMenu,
  SidebarMenuButton,
  SidebarMenuItem,
} from "@/components/ui/sidebar"

export function VersionSwitcher({
  versions,
  defaultVersion,
}: {
  versions: string[]
  defaultVersion: string
}) {
  const [selectedVersion, setSelectedVersion] = React.useState(defaultVersion)

  return (
    <SidebarMenu>
      <SidebarMenuItem>
        <DropdownMenu>
          <DropdownMenuTrigger asChild>
            <SidebarMenuButton
              size="lg"
              className="rf:data-[state=open]:bg-sidebar-accent rf:data-[state=open]:text-sidebar-accent-foreground"
            >
              <div className="rf:bg-sidebar-primary rf:text-sidebar-primary-foreground rf:flex rf:aspect-square rf:size-8 rf:items-center rf:justify-center rf:rounded-lg">
                <GalleryVerticalEnd className="rf:size-4" />
              </div>
              <div className="rf:flex rf:flex-col rf:gap-0.5 rf:leading-none">
                <span className="rf:font-medium">Documentation</span>
                <span className="rf:">v{selectedVersion}</span>
              </div>
              <ChevronsUpDown className="rf:ml-auto" />
            </SidebarMenuButton>
          </DropdownMenuTrigger>
          <DropdownMenuContent
            className="rf:w-(--radix-dropdown-menu-trigger-width)"
            align="start"
          >
            {versions.map((version) => (
              <DropdownMenuItem
                key={version}
                onSelect={() => setSelectedVersion(version)}
              >
                v{version}{" "}
                {version === selectedVersion && <Check className="rf:ml-auto" />}
              </DropdownMenuItem>
            ))}
          </DropdownMenuContent>
        </DropdownMenu>
      </SidebarMenuItem>
    </SidebarMenu>
  )
}
