import {defineConfig} from 'vite'
import react from '@vitejs/plugin-react-swc'
import tailwindcss from '@tailwindcss/vite';
import path from 'path';
import {fileURLToPath, URL} from 'node:url';
import injectProcessEnv from 'rollup-plugin-inject-process-env';

// https://vite.dev/config/
export default defineConfig(({mode}) => {
  return {
    plugins: [react(), tailwindcss()],
    resolve: {
      alias: {
        '@': path.resolve(__dirname, './src'),
      },
    },
    build: {
      outDir: '../components/react_flow/dist',
      sourcemap: mode === 'development',
      minify: mode !== 'development',
      emptyOutDir: true,
      rollupOptions: {
        output: {
          entryFileNames: '[name].js',
          chunkFileNames: '[name]-[hash].js',
          assetFileNames: '[name].[ext]',
        },
        plugins: [
          injectProcessEnv({
            NODE_ENV: process.env.NODE_ENV,
          }),
        ]
      },
      lib: {
        formats: ['es'],
        entry: {
          react_flow: fileURLToPath(new URL('src/main.tsx', import.meta.url)),
        }
      }
    },
    server: {
      host: '0.0.0.0',
      port: 5173,
      strictPort: true,
      // @ts-ignore
      origin: `${process.env.DDEV_PRIMARY_URL.replace(/:\d+$/, "")}:5173`,
    },
    cors: {
      origin: /https?:\/\/([A-Za-z0-9\-\.]+)?(\.ddev\.site)(?::\d+)?$/,
    },
  }
});
